<?php
/**
 * Custom functions for the theme settings.
 *
 * @package    Rexus
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Allowed embed, script and meta in textarea.
 *
 * @since  1.0.0
 */
function rexus_change_santiziation() {
	remove_filter( 'of_sanitize_textarea', 'of_sanitize_textarea' );
	add_filter( 'of_sanitize_textarea', 'rexus_sanitize_textarea' );
}
add_action( 'admin_init', 'rexus_change_santiziation', 100 );

/**
 * Custom sanitization for textarea
 *
 * @since  1.0.0
 * @param  array  $input
 * @return array
 */
function rexus_sanitize_textarea( $input ) {
	$output = stripslashes( $input );
	return $output;
}

/** 
 * Loads an additional CSS file for the options panel.
 *
 * @since  1.0.0
 */
if ( is_admin() ) {
	$of_page= 'appearance_page_options-framework';
	add_action( "admin_print_styles-$of_page", 'rexus_optionsframework_custom_css', 100 );
}
function rexus_optionsframework_custom_css () {
	wp_enqueue_style( 'rexus-options-framework-css', trailingslashit( get_stylesheet_directory_uri() ) .'admin/css/op-custom.css' );
}

/** 
 * This function adds the html that will appear in the sidebar module of the
 * options panel.
 *
 * @since  1.0.0
 */
function rexus_settings_sidebar() { ?>

	<div id="optionsframework-sidebar">
		<div class="metabox-holder">

			<div class="postbox">
				<h3><?php _e( 'Follow Us!', 'rexus' ); ?></h3>
				<div class="inside">
					<span class="tjsocial">
						<a href="https://twitter.com/theme_junkie" class="twitter-follow-button" data-show-count="false">Follow @theme_junkie</a>
						<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0],p=/^http:/.test(d.location)?'http':'https';if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src=p+'://platform.twitter.com/widgets.js';fjs.parentNode.insertBefore(js,fjs);}}(document, 'script', 'twitter-wjs');</script>
					</span>
					<span class="tjsocial">
						<div class="fb-like" data-href="https://www.facebook.com/themejunkies" data-width="50" data-layout="button_count" data-action="like" data-show-faces="false" data-share="false"></div>
						<div id="fb-root"></div>
						<script>(function(d, s, id) {
						  var js, fjs = d.getElementsByTagName(s)[0];
						  if (d.getElementById(id)) return;
						  js = d.createElement(s); js.id = id;
						  js.src = "//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.0";
						  fjs.parentNode.insertBefore(js, fjs);
						}(document, 'script', 'facebook-jssdk'));</script>
					</span>
				</div>
			</div>

			<div class="postbox">
				<h3><?php _e( 'Useful Links', 'rexus' ); ?></h3>
				<div class="inside">
					<ul class="ul-disc">
						<li><a href="https://demo.theme-junkie.com/rexus/wp-content/themes/rexus/readme/documentation.html" target="_blank"><?php _e( 'Documentation', 'rexus' ) ?></a></li>
						<li><a href="http://www.theme-junkie.com/forum/" target="_blank"><?php _e( 'Support Forum', 'rexus' ) ?></a></li>
						<li><a href="http://www.theme-junkie.com/affiliates/" target="_blank"><?php _e( 'Affiliate Program', 'rexus' ) ?></a></li>
						<li><a href="http://feeds.feedburner.com/ThemeJunkie" target="_blank"><?php _e( 'Subscribe to Our Blog', 'rexus' ) ?></a></li>
					</ul>
				</div>
			</div>

		</div>
	</div>

<?php }
add_action( 'optionsframework_after', 'rexus_settings_sidebar' );

/**
 * Favicon output.
 *
 * @since 1.0.0
 */
function rexus_favicon_output() {
	$favicon = of_get_option( 'rexus_favicon' );

	if ( !empty( $favicon ) ) {
		echo '<link href="' . esc_url( $favicon ) . '" rel="icon">' . "\n";
	}

}
add_action( 'wp_head', 'rexus_favicon_output', 5 );

/**
 * Add Custom Color Scheme Styles.
 *
 * @since 1.0.0
 */
function rexus_color_scheme() {

	// Get the color schemes.
	$color = of_get_option( 'rexus_colors', 'orange' );
	
	// Enqueue the stylesheet.
	wp_enqueue_style( 'rexus-color-schemes', trailingslashit( get_template_directory_uri() ) . 'assets/colors/' . $color . '.css', null, null, 'all' );
}
add_action( 'wp_enqueue_scripts', 'rexus_color_scheme', 10 );

/**
 * Background pattern.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function rexus_bg_pattern_class( $classes ) {

	$pattern = of_get_option( 'rexus_bg_pattern', 'bg-default' );
	
	if ( 'bg-1' === $pattern ) {
		$classes[] = 'bg-pattern-1';
	} elseif ( 'bg-2' === $pattern ) {
		$classes[] = 'bg-pattern-2';
	} elseif ( 'bg-3' === $pattern ) {
		$classes[] = 'bg-pattern-3';
	} elseif ( 'bg-4' === $pattern ) {
		$classes[] = 'bg-pattern-4';
	} elseif ( 'bg-5' === $pattern ) {
		$classes[] = 'bg-pattern-5';
	} elseif ( 'bg-6' === $pattern ) {
		$classes[] = 'bg-pattern-6';
	} elseif ( 'bg-7' === $pattern ) {
		$classes[] = 'bg-pattern-7';
	} elseif ( 'bg-8' === $pattern ) {
		$classes[] = 'bg-pattern-8';
	} elseif ( 'bg-9' === $pattern ) {
		$classes[] = 'bg-pattern-9';
	} elseif ( 'bg-10' === $pattern ) {
		$classes[] = 'bg-pattern-10';
	} elseif ( 'bg-11' === $pattern ) {
		$classes[] = 'bg-pattern-11';
	} elseif ( 'bg-12' === $pattern ) {
		$classes[] = 'bg-pattern-12';
	} elseif ( 'bg-13' === $pattern ) {
		$classes[] = 'bg-pattern-13';
	} elseif ( 'bg-14' === $pattern ) {
		$classes[] = 'bg-pattern-14';
	} elseif ( 'bg-15' === $pattern ) {
		$classes[] = 'bg-pattern-15';
	} else {
		$classes[] = 'no-pattern';
	}
		
	return $classes;
}
add_filter( 'body_class', 'rexus_bg_pattern_class' );

/**
 * Single post advertisement.
 * Before content.
 *
 * @since  1.0.0
 */
function rexus_single_ad_before( $content ) {
	$ad = of_get_option( 'rexus_ad_single_before' );

	if ( is_single() ) {
		$content = $ad . $content;
	} else {
		$content;
	}

	return $content;

}
add_action( 'the_content', 'rexus_single_ad_before' );

/**
 * Single post advertisement.
 * After content.
 *
 * @since  1.0.0
 */
function rexus_single_ad_after( $content ) {
	$ad = of_get_option( 'rexus_ad_single_after' );

	if ( is_single() ) {
		$content = $content . $ad;
	} else {
		$content;
	}

	return $content;

}
add_action( 'the_content', 'rexus_single_ad_after' );

/**
 * Header Code
 *
 * @since  1.0.0
 */
function rexus_header_code() {
	$header_code = of_get_option( 'rexus_script_head' );

	if ( !empty( $header_code ) ) {
		echo stripslashes( $header_code ) . "\n";
	}

}
add_action( 'wp_head', 'rexus_header_code', 20 );

/**
 * Footer Code
 *
 * @since  1.0.0
 */
function rexus_footer_code() {
	$footer_code = of_get_option( 'rexus_script_footer' );

	if ( !empty( $footer_code ) ) {
		echo stripslashes( $footer_code ) . "\n";
	}

}
add_action( 'wp_footer', 'rexus_footer_code', 20 );