<?php
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 *
 * @package    Rexus
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower( $themename ) );

	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );

}

/**
 * Defines an array of options that will be used to generate the settings page 
 * and be saved in the database.
 *
 * @since  1.0.0
 * @access public
 */
function optionsframework_options() {

	$options = array();

	// Pull all tags into an array.
	$tags = array();
	$tags_obj = get_tags();
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_html( $tag->name );
	}

	// Background thumbnail path.
	$imgpath =  get_template_directory_uri() . '/assets/img/bg/';

	$options = array();

	$options[] = array(
		'name' => __( 'General', 'rexus' ),
		'type' => 'heading'
	);

	$options['rexus_logo'] = array(
		'name' => __( 'Logo Uploader', 'rexus' ),
		'desc' => __( 'Upload your custom logo, it will automatically replace the Site Title', 'rexus' ),
		'id'   => 'rexus_logo',
		'type' => 'upload'
	);

	$options[] = array(
		'name' => __( 'Favicon Uploader', 'rexus' ),
		'desc' => __( 'Upload your custom favicon.', 'rexus' ),
		'id'   => 'rexus_favicon',
		'type' => 'upload'
	);

	$options[] = array(
		'name'  => __( 'FeedBurner URL', 'rexus' ),
		'desc'  => __( 'Enter your full FeedBurner URL. If you wish to use FeedBurner over the standard WordPress feed.', 'rexus' ),
		'id'    => 'rexus_feedburner_url',
		'placeholder' => 'http://feeds.feedburner.com/ThemeJunkie',
		'type'  => 'text'
	);

	$options[] = array(
		'name' => __( 'Style Switcher', 'rexus' ),
		'desc' => __( 'Enable style switcher to preview the skins and the backgroun pattern on front-end.', 'rexus' ),
		'id'   => 'rexus_switcher',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Responsive Layout?', 'rexus' ),
		'desc' => __( 'Enable mobile and tablet optimizations layout.', 'rexus' ),
		'id'   => 'rexus_responsive',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name'    => __( 'Colors', 'rexus' ),
		'desc'    => __( 'Pick a skin/color you like.', 'rexus' ),
		'id'      => 'rexus_colors',
		'type'    => 'select',
		'std'     => 'blue',
		'options' => array(
			'blue'        => __( 'Blue', 'rexus' ),
			'beige'       => __( 'Beige', 'rexus' ),
			'brown'       => __( 'Brown', 'rexus' ),
			'celadon'     => __( 'Celadon', 'rexus' ),
			'cherry'      => __( 'Cherry', 'rexus' ),
			'cyan'        => __( 'Cyan', 'rexus' ),
			'deep-blue'   => __( 'Deep Blue', 'rexus' ),
			'dirty-green' => __( 'Dirty Green', 'rexus' ),
			'gray'        => __( 'Gray', 'rexus' ),
			'green'       => __( 'Green', 'rexus' ),
			'navy'        => __( 'Navy', 'rexus' ),
			'olive'       => __( 'Olive', 'rexus' ),
			'orange'      => __( 'Orange', 'rexus' ),
			'peach'       => __( 'Peach', 'rexus' ),
			'pink'        => __( 'Pink', 'rexus' ),
			'purple'      => __( 'Purple', 'rexus' ),
			'red'         => __( 'Red', 'rexus' ),
			'yellow'      => __( 'Yellow', 'rexus' ),
		)
	);

	$options[] = array(
		'name'    => __( 'Background Pattern', 'rexus' ),
		'desc'    => sprintf( __( 'Pick the background pattern or you can set up %1$syour own custom background%2$s.', 'rexus' ), '<a href="' . esc_url( admin_url( 'themes.php?page=custom-background' ) ) . '">', '</a>' ),
		'id'      => 'rexus_bg_pattern',
		'std'     => 'bg-default',
		'type'    => 'images',
		'options' => array(
			'bg-default' => $imgpath . '0.png',
			'bg-1'       => $imgpath . '1.png',
			'bg-2'       => $imgpath . '2.png',
			'bg-3'       => $imgpath . '3.png',
			'bg-4'       => $imgpath . '4.png',
			'bg-5'       => $imgpath . '5.png',
			'bg-6'       => $imgpath . '6.png',
			'bg-7'       => $imgpath . '7.png',
			'bg-8'       => $imgpath . '8.png',
			'bg-9'       => $imgpath . '9.png',
			'bg-10'      => $imgpath . '10.png',
			'bg-11'      => $imgpath . '11.png',
			'bg-12'      => $imgpath . '12.png',
			'bg-13'      => $imgpath . '13.png',
			'bg-14'      => $imgpath . '14.png',
			'bg-15'      => $imgpath . '15.png',
		)
	);

	$options[] = array(
		'name' => __( 'Home Page', 'rexus' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => '',
		'desc' => __( 'Featured Posts is a colorful posts on home page. If you want to show it, please make sure you select the tag which have at least 7 posts.', 'rexus' ),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'Display Featured Posts', 'rexus' ),
		'desc' => __( 'Enable the Featured Posts area on home page.', 'rexus' ),
		'id'   => 'rexus_enable_featured',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name'    => __( 'Featured Posts Tag', 'rexus' ),
		'desc'    => __( 'Select a tag to be used as Featured Posts. Please note, <strong>you must have at least 7 articles in the tag.</strong>', 'rexus' ),
		'id'      => 'rexus_featured_tag',
		'type'    => 'select',
		'options' => $tags
	);

	$options[] = array(
		'name' => '',
		'desc' => __( 'Latest Videos will appear on home page below the featured posts. It will show the most recent 6 posts with Video format selected.', 'rexus' ),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'Display Latest Videos', 'rexus' ),
		'desc' => __( 'Enable the Latest Videos area on home page.', 'rexus' ),
		'id'   => 'rexus_enable_videos',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Custom Content', 'rexus' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => '',
		'desc' => __( 'Breaking News will appear on all pages at the top of your site.', 'rexus' ),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'Display Breaking News', 'rexus' ),
		'desc' => __( 'Enable the breaking news area on home page.', 'rexus' ),
		'id'   => 'rexus_enable_breaking',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name'    => __( 'Breaking News Tag', 'rexus' ),
		'desc'    => __( 'Select a tag to be used as Breaking News Posts', 'rexus' ),
		'id'      => 'rexus_breaking_tag',
		'type'    => 'select',
		'options' => $tags
	);

	$options[] = array(
		'name'  => __( 'Breaking News Number', 'rexus' ),
		'desc'  => __( 'Number of the Breaking News to show.', 'rexus' ),
		'id'    => 'rexus_breaking_num',
		'std'   => 10,
		'type'  => 'text'
	);

	$options[] = array(
		'name' => '',
		'desc' => __( 'The Editor\'s Picks posts will appear on all pages except Single Post.', 'rexus' ),
		'type' => 'info'
	);

	$options[] = array(
		'name' => __( 'Display Editor\'s Picks', 'rexus' ),
		'desc' => __( 'Enable the editor\'s picks area.', 'rexus' ),
		'id'   => 'rexus_enable_editor_picks',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name'    => __( 'Editor\'s Picks Tag', 'rexus' ),
		'desc'    => __( 'Select a tag to be used as Editor\'s Picks Posts', 'rexus' ),
		'id'      => 'rexus_editor_picks_tag',
		'type'    => 'select',
		'options' => $tags
	);

	$options[] = array(
		'name'  => __( 'Editor\'s Picks Number', 'rexus' ),
		'desc'  => __( 'Number of the Editor\'s Picks to show.', 'rexus' ),
		'id'    => 'rexus_editor_picks_num',
		'std'   => 10,
		'type'  => 'text'
	);

	$options[] = array(
		'name' => __( 'Single Post', 'rexus' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Display post navigation', 'rexus' ),
		'desc' => __( 'Shows links to the next and previous article.', 'rexus' ),
		'id'   => 'rexus_post_nav',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Display author info ', 'rexus' ),
		'desc' => __( 'Enable the author biographical info.', 'rexus' ),
		'id'   => 'rexus_post_author',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Display share links', 'rexus' ),
		'desc' => __( 'Enable the share links.', 'rexus' ),
		'id'   => 'rexus_post_share',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Display related posts', 'rexus' ),
		'desc' => __( 'Enable the related posts.', 'rexus' ),
		'id'   => 'rexus_related_posts',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options[] = array(
		'name' => __( 'Before Content Advertisement', 'rexus' ),
		'desc' => __( 'Your ad will appear on single post before content.', 'rexus' ),
		'id'   => 'rexus_ad_single_before',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'After Content Advertisement', 'rexus' ),
		'desc' => __( 'Your ad will appear on single post after content.', 'rexus' ),
		'id'   => 'rexus_ad_single_after',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Social Links', 'rexus' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => '',
		'desc' => __( 'The social links will appear at the top of your site.', 'rexus' ),
		'type' => 'info'
	);

	$options['rexus_enable_social'] = array(
		'name' => __( 'Enable ', 'rexus' ),
		'desc' => __( 'Enable social links', 'rexus' ),
		'id'   => 'rexus_enable_social',
		'std'  => '1',
		'type' => 'checkbox'
	);

	$options['rexus_fb'] = array(
		'name' => __( 'Facebook', 'rexus' ),
		'desc' => __( 'Facebook profile url', 'rexus' ),
		'id'   => 'rexus_fb',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['rexus_tw'] = array(
		'name' => __( 'Twitter', 'rexus' ),
		'desc' => __( 'Twitter profile url', 'rexus' ),
		'id'   => 'rexus_tw',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['rexus_gplus'] = array(
		'name' => __( 'Google Plus', 'rexus' ),
		'desc' => __( 'Google Plus profile url', 'rexus' ),
		'id'   => 'rexus_gplus',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['rexus_pinterest'] = array(
		'name' => __( 'Pinterest', 'rexus' ),
		'desc' => __( 'Pinterest profile url', 'rexus' ),
		'id'   => 'rexus_pinterest',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['rexus_linkedin'] = array(
		'name' => __( 'LinkedIn', 'rexus' ),
		'desc' => __( 'LinkedIn profile url', 'rexus' ),
		'id'   => 'rexus_linkedin',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['rexus_feed'] = array(
		'name' => __( 'RSS Feed', 'rexus' ),
		'desc' => __( 'RSS Feed url', 'rexus' ),
		'id'   => 'rexus_feed',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options['rexus_newsletter'] = array(
		'name' => __( 'Newsletter', 'rexus' ),
		'desc' => __( 'Newsletter url', 'rexus' ),
		'id'   => 'rexus_newsletter',
		'placeholder' => 'http://',
		'type' => 'text'
	);

	$options[] = array(
		'name' => __( 'Advertisement', 'rexus' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name' => __( 'Header Advertisement', 'rexus' ),
		'desc' => __( 'Add your ad code to the text box. Recommended size 728x90', 'rexus' ),
		'id'   => 'rexus_header_ads',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Footer Advertisement', 'rexus' ),
		'desc' => __( 'Add your ad code to the text box. Recommended size 728x90', 'rexus' ),
		'id'   => 'rexus_footer_ads',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'Custom Code', 'rexus' ),
		'type' => 'heading'
	);

	$options['rexus_script_head'] = array(
		'name' => __( 'Header code', 'rexus' ),
		'desc' => __( 'If you need to add custom scripts to your header (meta tag verification, google fonts url), you should enter them in the box. They will be added before &lt;/head&gt; tag', 'rexus' ),
		'id'   => 'rexus_script_head',
		'type' => 'textarea'
	);

	$options['rexus_script_footer'] = array(
		'name' => __( 'Footer code', 'rexus' ),
		'desc' => __( 'If you need to add custom scripts to your footer (like google analytic script), you should enter them in the box. They will be added before &lt;/body&gt; tag', 'rexus' ),
		'id'   => 'rexus_script_footer',
		'type' => 'textarea'
	);

	$options[] = array(
		'name' => __( 'bbPress', 'rexus' ),
		'type' => 'heading'
	);

	$options[] = array(
		'name'    => __( 'bbPress Page Layout', 'rexus' ),
		'desc'    => __( 'This setting is only applied to all bbPress pages.', 'rexus' ),
		'id'      => 'rexus_bbpress_layout',
		'type'    => 'radio',
		'std'     => '1c',
		'options' => array(
			'1c'   => _x( 'Full Width', 'bbPress Layout', 'rexus' ),
			'2c-l' => _x( '2 Columns: Content / Sidebar', 'bbPress Layout', 'rexus' ),
			'2c-r' => _x( '2 Columns: Sidebar / Content', 'bbPress Layout', 'rexus' )
		)
	);

	/* Return the theme settings data. */
	return $options;
}