<?php
/**
 * Accordions widget.
 *
 * @package    Rexus
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class Rexus_Accordions_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-rexus-accordion accordion-widget accordion',
			'description' => __( 'Display custom content with accordions.', 'rexus' )
		);

		// Create the widget.
		parent::__construct(
			'rexus-accordion',                   // $this->id_base
			__( '&raquo; Accordions', 'rexus' ), // $this->name
			$widget_options                      // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

		// Display the accordion content.
		if ( !empty( $instance['title_1'] ) && !empty( $instance['content_1'] ) ) {
			echo '<h3><span class="ui-accordion-header-icon ui-icon ui-accordion-icon ui-accordion-fa fa-active"></span>' . esc_attr( $instance['title_1'] ) . '</h3>';
			echo '<div><p>' . stripslashes( $instance['content_1'] ) . '</p></div>';
		}

		if ( !empty( $instance['title_2'] ) && !empty( $instance['content_2'] ) ) {
			echo '<h3><span class="ui-accordion-header-icon ui-icon ui-accordion-icon ui-accordion-fa"></span>' . esc_attr( $instance['title_2'] ) . '</h3>';
			echo '<div><p>' . stripslashes( $instance['content_2'] ) . '</p></div>';
		}

		if ( !empty( $instance['title_3'] ) && !empty( $instance['content_3'] ) ) {
			echo '<h3><span class="ui-accordion-header-icon ui-icon ui-accordion-icon ui-accordion-fa"></span>' . esc_attr( $instance['title_3'] ) . '</h3>';
			echo '<div><p>' . stripslashes( $instance['content_3'] ) . '</p></div>';
		}

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title_1']   = strip_tags( $new_instance['title_1'] );
		$instance['content_1'] = stripslashes( $new_instance['content_1'] );
		$instance['title_2']   = strip_tags( $new_instance['title_2'] );
		$instance['content_2'] = stripslashes( $new_instance['content_2'] );
		$instance['title_3']   = strip_tags( $new_instance['title_3'] );
		$instance['content_3'] = stripslashes( $new_instance['content_3'] );

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title_1'   => '',
			'content_1' => '',
			'title_2'   => '',
			'content_2' => '',
			'title_3'   => '',
			'content_3' => ''
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>
		<style>.acc-title{ background: #f2f2f2; padding: 10px; margin-bottom: 0; }</style>

		<h4 class="acc-title"><?php _e( 'Content 1', 'rexus' ); ?></h4>
		<p>
			<label for="<?php echo $this->get_field_id( 'title_1' ); ?>">
				<?php _e( 'Title 1', 'rexus' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title_1' ); ?>" name="<?php echo $this->get_field_name( 'title_1' ); ?>" value="<?php echo esc_attr( $instance['title_1'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'content_1' ); ?>">
				<?php _e( 'Content 1', 'rexus' ); ?>
			</label>
			<textarea class="widefat" name="<?php echo $this->get_field_name( 'content_1' ); ?>" id="<?php echo $this->get_field_id( 'content_1' ); ?>" cols="30" rows="6"><?php echo stripslashes( $instance['content_1'] ); ?></textarea>
		</p>

		<h4 class="acc-title"><?php _e( 'Content 2', 'rexus' ); ?></h4>
		<p>
			<label for="<?php echo $this->get_field_id( 'title_2' ); ?>">
				<?php _e( 'Title 2', 'rexus' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title_2' ); ?>" name="<?php echo $this->get_field_name( 'title_2' ); ?>" value="<?php echo esc_attr( $instance['title_2'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'content_2' ); ?>">
				<?php _e( 'Content 2', 'rexus' ); ?>
			</label>
			<textarea class="widefat" name="<?php echo $this->get_field_name( 'content_2' ); ?>" id="<?php echo $this->get_field_id( 'content_2' ); ?>" cols="30" rows="6"><?php echo stripslashes( $instance['content_2'] ); ?></textarea>
		</p>

		<h4 class="acc-title"><?php _e( 'Content 3', 'rexus' ); ?></h4>
		<p>
			<label for="<?php echo $this->get_field_id( 'title_3' ); ?>">
				<?php _e( 'Title 3', 'rexus' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title_3' ); ?>" name="<?php echo $this->get_field_name( 'title_3' ); ?>" value="<?php echo esc_attr( $instance['title_3'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'content_3' ); ?>">
				<?php _e( 'Content 3', 'rexus' ); ?>
			</label>
			<textarea class="widefat" name="<?php echo $this->get_field_name( 'content_3' ); ?>" id="<?php echo $this->get_field_id( 'content_3' ); ?>" cols="30" rows="6"><?php echo stripslashes( $instance['content_3'] ); ?></textarea>
		</p>

	<?php

	}

}