<?php
/**
 * Enqueue scripts and styles.
 *
 * @package    Rexus
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Loads the theme styles & scripts.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/wp_enqueue_script
 * @link  http://codex.wordpress.org/Function_Reference/wp_enqueue_style
 */
function rexus_enqueue() {

	// if WP_DEBUG and/or SCRIPT_DEBUG turned on, load the unminified styles & script.
	if ( ! is_child_theme() && WP_DEBUG || SCRIPT_DEBUG ) {

		// Load main stylesheet
		wp_enqueue_style( 'rexus-style', get_stylesheet_uri() );

		// Load custom js plugins.
		wp_enqueue_script( 'rexus-plugins', trailingslashit( get_template_directory_uri() ) . 'assets/js/plugins.js', array( 'jquery' ), null, true );

		// Load custom js methods.
		wp_enqueue_script( 'rexus-scripts', trailingslashit( get_template_directory_uri() ) . 'assets/js/main.js', array( 'jquery' ), null, true );

	} else {

		// Load main stylesheet
		wp_enqueue_style( 'rexus-style', trailingslashit( get_template_directory_uri() ) . 'style.min.css' );

		// If child theme is active, load the stylesheet.
		if ( is_child_theme() ) {
			wp_enqueue_style( 'rexus-child-style', get_stylesheet_uri() );
		}

		// Load custom js plugins.
		wp_enqueue_script( 'rexus-scripts', trailingslashit( get_template_directory_uri() ) . 'assets/js/rexus.min.js', array( 'jquery' ), null, true );

	}

	// Load responsive stylesheet.
	if ( of_get_option( 'rexus_responsive', '1' ) ) {
		wp_enqueue_style( 'rexus-responsive', trailingslashit( get_template_directory_uri() ) . 'assets/css/responsive.css' );
	}

	// Load bootstrap js plugins.
	wp_enqueue_script( 'rexus-bootstrap-js', trailingslashit( get_template_directory_uri() ) . 'assets/js/bootstrap.min.js', array( 'jquery' ), null, true );

	// Loads style switcher assets.
	if ( of_get_option( 'rexus_switcher', '1' ) ) {
		wp_enqueue_style( 'rexus-switcher-style', trailingslashit( get_template_directory_uri() ) . 'assets/css/switcher.css', array(), null );
		wp_enqueue_script( 'rexus-switcher-script', trailingslashit( get_template_directory_uri() ) . 'assets/js/switcher.js', array( 'jquery' ), null, true );
		wp_localize_script( 'rexus-switcher-script', 'rexus_path', array( 'assets' => get_template_directory_uri() . '/assets/' ) );
	}

	// Load comment-reply script.
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Localize a string.
	wp_localize_script( 'rexus-scripts', 'rexus_localize', array( 'title'  => __( 'Breaking', 'rexus' ) ) );

}
add_action( 'wp_enqueue_scripts', 'rexus_enqueue' );

/**
 * Loads HTML5 Shiv & Respond js file.
 * 
 * @since  1.0.0
 */
function rexus_special_scripts() {
?>
<!--[if lte IE 9]>
<script src="<?php echo trailingslashit( get_template_directory_uri() ) . 'assets/js/html5shiv.js'; ?>"></script>
<![endif]-->
<?php
}
add_action( 'wp_head', 'rexus_special_scripts', 15 );

/**
 * js / no-js script.
 *
 * @since  1.0.0
 */
function rexus_no_js_script() {
?>
<script>document.documentElement.className = 'js';</script>
<?php
}
add_action( 'wp_footer', 'rexus_no_js_script' );