<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 * 
 * @package    Rexus
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'rexus_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since 1.0.0
 */
function rexus_posted_on() {
	$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	printf( __( 'by <span class="entry-author">%1$s</span> on %2$s', 'rexus' ),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s">%2$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_html( get_the_author() )
		),
		sprintf( '<a href="%1$s" rel="bookmark">%2$s</a>',
			esc_url( get_permalink() ),
			$time_string
		)
	);

	/* translators: used between list items, there is a space after the comma */
	$category_list = get_the_category_list( __( ', ', 'rexus' ) );
	if ( is_single() && rexus_categorized_blog() ) {
		printf( __( ' in <span class="entry-categories">%s</span>', 'rexus' ), $category_list );
	}

}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function rexus_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'rexus_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'rexus_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so rexus_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so rexus_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in rexus_categorized_blog.
 *
 * @since 1.0.0
 */
function rexus_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'rexus_categories' );
}
add_action( 'edit_category', 'rexus_category_transient_flusher' );
add_action( 'save_post',     'rexus_category_transient_flusher' );

if ( ! function_exists( 'rexus_site_branding' ) ) :
/**
 * Site branding for the site.
 * 
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 * 
 * @since  1.0.0
 */
function rexus_site_branding() {

	$logo = of_get_option( 'rexus_logo' );

	// Check if logo available, then display it.
	if ( $logo ) :
		echo '<div id="logo">' . "\n";
			echo '<a href="' . esc_url( get_home_url() ) . '" rel="home">' . "\n";
				echo '<img src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<div id="logo"><h1 class="site-title"><a href="' . esc_url( get_home_url() ) . '" rel="home">' . esc_attr( get_bloginfo( 'name' ) ) . '</a></h1></div>';
	endif;

}
endif;

if ( ! function_exists( 'rexus_social_links' ) ) :
/**
 * Social links
 *
 * @since  1.0.0
 */
function rexus_social_links() {

	// Get option value.
	$enable     = of_get_option( 'rexus_enable_social', '1' );
	$facebook   = of_get_option( 'rexus_fb' );
	$twitter    = of_get_option( 'rexus_tw' );
	$gplus      = of_get_option( 'rexus_gplus' );
	$pinterest  = of_get_option( 'rexus_pinterest' );
	$linkedin   = of_get_option( 'rexus_linkedin' );
	$feed       = of_get_option( 'rexus_feed' );
	$newsletter = of_get_option( 'rexus_newsletter' );

	// Check if social links option enabled.
	if ( $enable ) {
		echo '<div class="header-social-icons">';

			if ( $facebook ) {
				echo '<a class="tooltip" href="' . esc_url( $facebook ) . '" title="Facebook"><i class="fa fa-facebook"></i></a>';
			}
			if ( $twitter ) {
				echo '<a class="tooltip" href="' . esc_url( $twitter ) . '" title="Twitter"><i class="fa fa-twitter"></i></a>';
			}
			if ( $gplus ) {
				echo '<a class="tooltip" href="' . esc_url( $gplus ) . '" title="GooglePlus"><i class="fa fa-google-plus"></i></a>';
			}
			if ( $pinterest ) {
				echo '<a class="tooltip" href="' . esc_url( $pinterest ) . '" title="Pinterest"><i class="fa fa-pinterest"></i></a>';
			}
			if ( $linkedin ) {
				echo '<a class="tooltip" href="' . esc_url( $linkedin ) . '" title="LinkedIn"><i class="fa fa-linkedin"></i></a>';
			}
			if ( $feed ) {
				echo '<a class="tooltip" href="' . esc_url( $feed ) . '" title="RSS"><i class="fa fa-rss"></i></a>';
			}
			if ( $newsletter ) {
				echo '<a class="tooltip" href="' . esc_url( $newsletter ) . '" title="Newsletter"><i class="fa fa-envelope-o"></i></a>';
			}

		echo '</div>';
	}

}
endif;

if ( ! function_exists( 'rexus_featured_posts' ) ) :
/**
 * Featured colorful posts.
 *
 * @since  1.0.0
 */
function rexus_featured_posts() {
	global $post;

	$enable = of_get_option( 'rexus_enable_featured', '1' ); // Enable disable area.
	$tag    = of_get_option( 'rexus_featured_tag' ); // Get the user selected tag for the featured posts.

	// Bail if disable by user.
	if ( ! $enable ) {
		return;
	}

	// Get any existing copy of our transient data.
	if ( false === ( $featured = get_transient( 'rexus_featured_posts' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => 7
		);

		if ( ! empty( $tag ) ) {
			$args['tag_id'] = $tag;
		}

		// The post query
		$featured = get_posts( $args );

		// Store the transient.
		set_transient( 'rexus_featured_posts', $featured );
	}

	// Check if the post(s) exist.
	if ( $featured ) :

		$html = '<section id="featured-content" class="clearfix">';

			$html .= '<section id="featured-content" class="clearfix">';

				$i         = 0;
				$class     = '';
				$thumbsize = '';

				foreach ( $featured as $post ) :
					setup_postdata( $post );

					if ( $i % 4 ) { 
						$class     = 'featured-small';
						$thumbsize = 'rexus-featured-thumb-s';
					} else {
						$class     = 'featured-big';
						$thumbsize = 'rexus-featured-thumb';
					}

					$html .= '<div id="featured-' . $i . '" class="featured-box featured-' . $i . ' ' . $class. ' gradient gradient-' . $i . '">';
						$html .= '<a href="' . get_permalink( $post->ID ) . '" rel="bookmark">';
							if ( has_post_thumbnail( $post->ID ) ) {
								$html .=  get_the_post_thumbnail( $post->ID, $thumbsize, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
							}
							$html .= '<div class="entry-header gradient-tran-white"><h2 class="entry-title">' . get_the_title( $post->ID ) . '</h2></div>';
						$html .= '</a>';	
					$html .= '</div>';
					$i++;
				endforeach;
			$html .= '</section>';

		$html .= '</section><!-- #featured-content -->';

	// End check.
	endif;

	// Restore original Post Data.
	wp_reset_postdata();

	// Display the posts.
	if ( ! empty( $html ) ) {
		echo $html;
	}

}
endif;

/**
 * Flush out the transients used in rexus_featured_posts.
 *
 * @since 1.0.0
 */
function rexus_featured_transient_flusher() {
	delete_transient( 'rexus_featured_posts' );
}
add_action( 'save_post', 'rexus_featured_transient_flusher' );
add_action( 'optionsframework_after_validate', 'rexus_featured_transient_flusher' );

if ( ! function_exists( 'rexus_promo_video' ) ) :
/**
 * Video Promo.
 *
 * @since  1.0.0
 */
function rexus_promo_video() {
	global $post;

	$enable = of_get_option( 'rexus_enable_videos', '1' ); // Enable disable area.

	// Bail if disable by user.
	if ( ! $enable ) {
		return;
	}

	// Posts query arguments.
	$args = array(
		'post_type'      => 'post',
		'posts_per_page' => 1,
		'tax_query' => array(
			array(
				'taxonomy' => 'post_format',
				'field'    => 'slug',
				'terms'    => array( 'post-format-video' )
			)
		),
	);

	// The post query
	$promo = get_posts( $args );

	if ( $promo ) :

		$html = '<section id="video-promo" class="clearfix">';
			foreach ( $promo as $post ) :
				setup_postdata( $post );
				$html .= '<span class="left"><i class="fa fa-video-camera"></i> ';
					$html .= '<a href="' . get_permalink( $post->ID ) . '" rel="bookmark">' . esc_attr( get_the_title( $post->ID ) ) . '</a>';
				$html .= '</span>';
			endforeach;
			$html .= '<span class="right"><a href="' . esc_url( get_post_format_link( 'video' ) ) . '">' . __( 'See More Videos', 'rexus' ) . '</a></span>';
		$html .= '</section>';

	// End check.
	endif;

	// Restore original Post Data.
	wp_reset_postdata();

	// Display the posts.
	if ( ! empty( $html ) ) {
		echo $html;
	}

}
endif;

if ( ! function_exists( 'rexus_videos' ) ) :
/**
 * Latest Videos.
 *
 * @since  1.0.0
 */
function rexus_videos() {
	global $post;

	$enable = of_get_option( 'rexus_enable_videos', '1' ); // Enable disable area.

	// Bail if disable by user.
	if ( ! $enable ) {
		return;
	}

	// Return early if on single post.
	if ( is_single() ) {
		return;
	}

	// Get any existing copy of our transient data.
	if ( false === ( $video = get_transient( 'rexus_video_posts' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => 5,
			'offset'         => 1,
			'tax_query' => array(
				array(
					'taxonomy' => 'post_format',
					'field'    => 'slug',
					'terms'    => array( 'post-format-video' )
				)
			),
		);

		// The post query
		$video = get_posts( $args );

		// Store the transient.
		set_transient( 'rexus_video_posts', $video );
	}

	// Check if the post(s) exist.
	if ( $video ) :

		$html = '<section id="video-slider" class="clearfix">';

			$html .= '<ul class="tabs-nav">';
				$i = 1;
				foreach ( $video as $post ) :
					setup_postdata( $post );
					$html .= '<li>';
						$html .= '<a href="#tab' . $i . '">';
							if ( has_post_thumbnail( $post->ID ) ) {
								$html .=  get_the_post_thumbnail( $post->ID, 'rexus-video-thumb', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
							}
							$html .= get_the_title( $post->ID );
							$html .= '<span class="video-icon"></span>';
						$html .= '</a>';
					$html .= '</li>';
					$i++;
				endforeach;
			$html .= '</ul>';

			$html .= '<div class="tabs-container">';
				$i = 1;
				foreach ( $video as $post ) :
					setup_postdata( $post );
					$html .= '<div class="tab-content" id="tab' . $i . '">';
						$media  = hybrid_media_grabber( array( 'type' => 'video', 'split_media' => false, 'width' => 680 ) );
						if ( $media ) {
							$html .= $media;
						} elseif ( has_post_thumbnail( $post->ID ) ) {
							$html .=  get_the_post_thumbnail( $post->ID, 'rexus-video-big-thumb', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
						}
					$html .= '</div>';
					$i++;
				endforeach;
			$html .= '</div>';

		$html .= '</section><!-- #video-slider -->';

	// End check.
	endif;

	// Restore original Post Data.
	wp_reset_postdata();

	// Display the posts.
	if ( ! empty( $html ) ) {
		echo $html;
	}

}
endif;

/**
 * Flush out the transients used in rexus_videos.
 *
 * @since 1.0.0
 */
function rexus_video_transient_flusher() {
	delete_transient( 'rexus_video_posts' );
}
add_action( 'save_post', 'rexus_video_transient_flusher' );
add_action( 'optionsframework_after_validate', 'rexus_video_transient_flusher' );

if ( ! function_exists( 'rexus_breaking_news' ) ) :
/**
 * Breaking news/posts query.
 *
 * @since  1.0.0
 */
function rexus_breaking_news() {
	global $post;

	$enable = of_get_option( 'rexus_enable_breaking', '1' ); // Enable disable area.
	$tag    = of_get_option( 'rexus_breaking_tag' ); // Get the user selected tag for the breaking news posts.
	$num    = of_get_option( 'rexus_breaking_num', 10 ); // Get the number of posts to show.

	// Bail if disable by user.
	if ( ! $enable ) {
		return;
	}

	// Return early if on single post.
	if ( is_single() ) {
		return;
	}

	// Get any existing copy of our transient data.
	if ( false === ( $breaking = get_transient( 'rexus_breaking_posts' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => absint( $num )
		);

		if ( ! empty( $tag ) ) {
			$args['tag_id'] = $tag;
		}

		// The post query
		$breaking = get_posts( $args );

		// Store the transient.
		set_transient( 'rexus_breaking_posts', $breaking );
	}

	// Check if the post(s) exist.
	if ( $breaking ) :

		$html = '<section id="breaking-news">';

			$html .= '<ul id="js-news" class="js-hidden">';
				foreach ( $breaking as $post ) :
					setup_postdata( $post );
					$html .= '<li class="newst-item">';
						$html .= '<a href="' . get_permalink( $post->ID ) . '" rel="bookmark">' . esc_attr( get_the_title( $post->ID ) ) . '</a>';	
					$html .= '</li>';
				endforeach;
			$html .= '</ul>';

		$html .= '</section><!-- #breaking-news -->';

	// End check.
	endif;

	// Restore original Post Data.
	wp_reset_postdata();

	// Display the posts.
	if ( ! empty( $html ) ) {
		echo $html;
	}

}
endif;

/**
 * Flush out the transients used in rexus_breaking_news.
 *
 * @since 1.0.0
 */
function rexus_breaking_transient_flusher() {
	delete_transient( 'rexus_breaking_posts' );
}
add_action( 'save_post', 'rexus_breaking_transient_flusher' );
add_action( 'optionsframework_after_validate', 'rexus_breaking_transient_flusher' );

if ( ! function_exists( 'rexus_editor_posts' ) ) :
/**
 * Editor's picks carousel posts.
 *
 * @since  1.0.0
 */
function rexus_editor_posts() {
	global $post;

	$enable = of_get_option( 'rexus_enable_editor_picks', '1' ); // Enable disable area.
	$tag    = of_get_option( 'rexus_editor_picks_tag' ); // Get the user selected tag for the editor's picks posts.
	$num    = of_get_option( 'rexus_editor_picks_num', 10 ); // Get the number of posts to show.

	// Bail if disable by user
	if ( ! $enable ) {
		return;
	}

	// Return early if on single post.
	if ( is_single() ) {
		return;
	}

	// Get any existing copy of our transient data.
	if ( false === ( $editor = get_transient( 'rexus_editor_picks_posts' ) ) ) {
		// It wasn't there, so regenerate the data and save the transient.
		
		// Posts query arguments.
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => absint( $num )
		);

		if ( ! empty( $tag ) ) {
			$args['tag_id'] = $tag;
		}

		// The post query
		$editor = get_posts( $args );

		// Store the transient.
		set_transient( 'rexus_editor_picks_posts', $editor );
	}

	// Check if the post(s) exist.
	if ( $editor ) :

		$html = '<div id="carousel-1" class="carousel-loop">';

			$html .= '<h2 class="section-title">' . __( 'Editor\'s Picks', 'rexus' ) . '</h2>';
			$html .= '<div class="jcarousel">';
				$html .= '<ul>';
					foreach ( $editor as $post ) :
						setup_postdata( $post );
						$html .= '<li>';
							$html .= '<article class="' . implode( ' ', get_post_class( '', $post->ID ) ) . '">';
								$html .= '<a href="' . get_permalink( $post->ID ) . '" rel="bookmark">';
									if ( has_post_thumbnail( $post->ID ) ) {
										$html .=  get_the_post_thumbnail( $post->ID, 'rexus-carousel-thumb', array( 'class' => 'entry-thumb', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
									}
									$html .= '<h2 class="entry-title">' . esc_attr( get_the_title( $post->ID ) ) . '</h1>';
									$html .= '<div class="entry-meta"><time datetime="' . get_the_date( 'c' ) . '">' . get_the_date() . '</time></div>';
									$html .= rexus_get_post_format_icons();
								$html .= '</a>';
							$html .= '</article>';
						$html .= '</li>';
					endforeach;
				$html .= '</ul>';
			$html .= '</div><!-- .jcarousel -->';

			if ( count( $editor ) > 4 ) {
				$html .= '<a href="#" class="jcarousel-control-prev"><i class="fa fa-chevron-left"></i></a>';
				$html .= '<a href="#" class="jcarousel-control-next"><i class="fa fa-chevron-right"></i></a>';
			} 

		$html .= '</div><!-- .carousel-loop -->';

	// End check.
	endif;

	// Restore original Post Data.
	wp_reset_postdata();

	// Display the posts.
	if ( ! empty( $html ) ) {
		echo $html;
	}

}
endif;

/**
 * Flush out the transients used in rexus_editor_posts.
 *
 * @since 1.0.0
 */
function rexus_editor_content_transient_flusher() {
	delete_transient( 'rexus_editor_picks_posts' );
}
add_action( 'save_post', 'rexus_editor_content_transient_flusher' );
add_action( 'optionsframework_after_validate', 'rexus_editor_content_transient_flusher' );

if ( ! function_exists( 'rexus_related_posts' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function rexus_related_posts() {
	global $post;

	// User selected to display the related posts or not.
	if ( ! of_get_option( 'rexus_related_posts', '1' ) ) {
		return;
	}

	// Only display related posts on single post.
	if ( ! is_single() ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( $post->ID, 'category', array( 'fields' => 'ids' ) );

	// Bail if term empty.
	if ( empty( $terms ) ) {
		return;
	}

	// Query arguments.
	$query = array(
		'tax_query' => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => 10,
		'exclude'        => $post->ID,
		'post_type'      => 'post',
	);

	// Allow plugins/themes developer to filter the default query.
	$query = apply_filters( 'rexus_related_posts_query', $query );

	// Perform the query.
	$related = get_posts( $query );
	
	if ( $related ) {

		$html = '<div id="carousel-1" class="carousel-loop">';

			$html .= '<h2 class="section-title">' . __( 'Related Posts', 'rexus' ) . '</h2>';
			$html .= '<div class="jcarousel">';
				$html .= '<ul>';
					foreach ( $related as $post ) :
						setup_postdata( $post );
						$html .= '<li>';
							$html .= '<article class="' . implode( ' ', get_post_class( '', $post->ID ) ) . '">';
								$html .= '<a href="' . get_permalink( $post->ID ) . '" rel="bookmark">';
									if ( has_post_thumbnail( $post->ID ) ) {
										$html .=  get_the_post_thumbnail( $post->ID, 'rexus-carousel-thumb', array( 'class' => 'entry-thumb', 'alt' => esc_attr( get_the_title( $post->ID ) ) ) );
									}
									$html .= '<h2 class="entry-title">' . esc_attr( get_the_title( $post->ID ) ) . '</h1>';
									$html .= '<div class="entry-meta"><time datetime="' . get_the_date( 'c' ) . '">' . get_the_date() . '</time></div>';
									$html .= rexus_get_post_format_icons();
								$html .= '</a>';
							$html .= '</article>';
						$html .= '</li>';
					endforeach;
				$html .= '</ul>';
			$html .= '</div><!-- .jcarousel -->';

			if ( count( $related ) > 4 ) {
				$html .= '<a href="#" class="jcarousel-control-prev"><i class="fa fa-chevron-left"></i></a>';
				$html .= '<a href="#" class="jcarousel-control-next"><i class="fa fa-chevron-right"></i></a>';
			} 

		$html .= '</div><!-- .carousel-loop -->';

	}

	// Restore original Post Data.
	wp_reset_postdata();

	if ( isset( $html ) ) {
		echo $html;
	}

}
endif;

if ( ! function_exists( 'rexus_social_share' ) ) :
/**
 * Social share.
 *
 * @since  1.0.0
 */
function rexus_social_share() {
	global $post;
?>
	<span class="entry-share-icons">
		<span class="entry-share-icons">
			<a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" class="tooltip" title="Facebook"><i class="fa fa-facebook"></i></a>
			<a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>&url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" class="tooltip" title="Twitter"><i class="fa fa-twitter"></i></a>
			<a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>" class="tooltip" title="GooglePlus"><i class="fa fa-google-plus"></i></a>
			<a href="https://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&media=<?php echo wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) ); ?>&description=<?php echo get_the_excerpt(); ?>" class="tooltip" title="Pinterest"><i class="fa fa-pinterest"></i></a>
			<a href="https://www.linkedin.com/shareArticle?mini=true&url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&title=<?php echo esc_attr( get_the_title( $post->ID ) ); ?>&summary=<?php echo get_the_excerpt(); ?>&source=<?php echo esc_attr( get_bloginfo( 'name' ) ) ?>" class="tooltip" title="LinkedIn"><i class="fa fa-linkedin"></i></a>
		</span>
	</span>
<?php
}
endif;

if ( ! function_exists( 'rexus_post_author' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function rexus_post_author() {

	// Bail if not on the single post.
	if ( ! is_single() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}

	// Bail if user don't want to display the author info via theme settings.
	if ( ! of_get_option( 'rexus_post_author', '1' ) ) {
		return;
	}
?>

	<section class="author-box clearfix">
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'rexus_author_bio_avatar_size', 72 ) ); ?>
		<h3 class="author-title">
			<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author"><?php echo strip_tags( get_the_author() ); ?></a>
		</h3>
		<p><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>
	</section><!-- .author-box -->

<?php
}
endif;

if ( ! function_exists( 'rexus_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function rexus_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'rexus' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'rexus' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">

			<?php echo get_avatar( $comment, 60 ); ?>
			
			<div class="comment-des">

				<div class="arrow-comment"></div>

				<div class="comment-by">
					<p class="author"><strong><?php echo get_comment_author_link(); ?></strong></p>
					<?php
						printf( '<p class="date"><a href="%1$s"><time datetime="%2$s">%3$s</time></a> - %4$s</p>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( __( '%1$s at %2$s', 'rexus' ), get_comment_date(), get_comment_time() ),
							sprintf( __( '%1$sEdit%2$s', 'rexus' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'rexus' ) . '">', '</a>' )
						);
					?>
					<span class="reply">
						<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'rexus' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
					</span><!-- .reply -->
				</div><!-- .comment-by -->

				<section class="comment-content comment">
					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'rexus' ); ?></p>
					<?php endif; ?>
					<?php comment_text(); ?>
				</section><!-- .comment-content -->

			</div><!-- .comment-des -->

		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'rexus_get_post_format_icons' ) ) :
/**
 * Post format icons
 *
 * @since  1.0.0
 * @return string The post format icon markup
 */
function rexus_get_post_format_icons() {

	// Set up empty variable.
	$icon = '';

	// If video format.
	if ( has_post_format( 'video' ) ) {
		$icon = '<span class="video-icon"></span>';
		
	// If image or gallery format.
	} elseif ( has_post_format( array( 'image', 'gallery' ) ) ) {
		$icon = '<span class="image-icon"></span>';
	}

	return apply_filters( 'rexus_format_icons', $icon );

}
endif;